pub struct UnknownRelation(pub String);Expand description
Parse error returned when a string does not match any canonical relation.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for UnknownRelation
impl Clone for UnknownRelation
Sourcefn clone(&self) -> UnknownRelation
fn clone(&self) -> UnknownRelation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnknownRelation
impl Debug for UnknownRelation
Sourceimpl Display for UnknownRelation
impl Display for UnknownRelation
Sourceimpl Error for UnknownRelation
Available on crate feature std only.
impl Error for UnknownRelation
Available on crate feature
std only.1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for UnknownRelation
impl PartialEq for UnknownRelation
Sourcefn eq(&self, other: &UnknownRelation) -> bool
fn eq(&self, other: &UnknownRelation) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UnknownRelation
impl StructuralPartialEq for UnknownRelation