#[non_exhaustive]pub enum RefusalReason {
AnonymousActor,
ExpectActorMismatch,
GateRefusal,
StrictOpFailure,
ParseError,
VerbRefused,
}Expand description
Stable reason attached to a refused kkernel exec invocation or operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AnonymousActor
The resolved actor was anonymous where attribution was required.
ExpectActorMismatch
The resolved actor did not match --expect-actor.
GateRefusal
A write was refused by the content secret gate.
StrictOpFailure
--strict observed at least one failed or aborted operation.
ParseError
The supplied operation expression could not be parsed.
VerbRefused
The requested verb was unknown or was not loaded.
Implementations
Sourceimpl RefusalReason
impl RefusalReason