Substrate discriminant — the 3 data types in khive (ADR-004).
Full substrate structs live in the sibling modules (note, entity,
event). This module provides the discriminant for typed dispatch and
persistence.
Enums
- Substrate
Error - Substrate
Kind - The 3 substrate types in khive OSS (ADR-004).